# 通用框架

> 标准化、兼容多个业务需求

## 输入

- 尽量统一一种或多种输入格式

## 输出

- 尽量统一一种或多种输出格式

## 参数配置

- 命令行：主要配置些常用参数，便于修改
- ZK配置参数：支持热更新
- Yaml文件配置参数

## 代码结构

- 入口函数：传入命令行参数

  ```python
  def main():
      fire.Fire(func)
  ```



